@@ -12,7 +12,7 @@ from mock import patch
 from molo.core.models import (
     ArticlePage, CmsSettings, Main,
     SiteLanguageRelation, Languages, SectionIndexPage, FooterIndexPage,
-    BannerIndexPage, TagIndexPage, BannerPage, ReactionQuestionIndexPage,
+    BannerIndexPage, TagIndexPage, BannerPage,
     Timezone, Tag, ArticlePageTags, Site, LanguageRelation
 )
 from molo.core import constants
@@ -52,9 +52,6 @@ class TestModels(TestCase, MoloTestCaseMixin):
         LanguageRelation.objects.create(
             page=self.main, language=self.english)
 
-        LanguageRelation.objects.create(
-            page=self.reaction_index, language=self.english)
-
         LanguageRelation.objects.create(
             page=self.banner_index, language=self.english)
 
@@ -163,19 +160,6 @@ class TestModels(TestCase, MoloTestCaseMixin):
         self.assertEqual(
             SectionIndexPage.objects.child_of(self.main2).count(), 1)
 
-    @pytest.mark.django_db(transaction=True)
-    def test_copy_method_of_reaction_index_wont_duplicate_index_pages(self):
-        LanguageRelation.objects.create(
-            page=ReactionQuestionIndexPage.objects.child_of(
-                self.main2).first(),
-            language=self.spanish
-        )
-        self.assertEqual(
-            ReactionQuestionIndexPage.objects.child_of(self.main2).count(), 1)
-        self.reaction_index.copy(to=self.main2)
-        self.assertEqual(
-            ReactionQuestionIndexPage.objects.child_of(self.main2).count(), 1)
-
     @pytest.mark.django_db(transaction=True)
     def test_copy_method_of_tag_index_wont_duplicate_index_pages(self):
         LanguageRelation.objects.create(
@@ -487,10 +471,6 @@ class TestModels(TestCase, MoloTestCaseMixin):
             'nav_tags-MAX_NUM_FORMS': 1000,
             'nav_tags-MIN_NUM_FORMS': 0,
             'nav_tags-TOTAL_FORMS': 0,
-            'reaction_questions-INITIAL_FORMS': 0,
-            'reaction_questions-MAX_NUM_FORMS': 1000,
-            'reaciction_questions-MIN_NUM_FORMS': 0,
-            'reaction_questions-TOTAL_FORMS': 0,
             'related_sections-INITIAL_FORMS': 0,
             'related_sections-MAX_NUM_FORMS': 1000,
             'related_sections-MIN_NUM_FORMS': 0,
@@ -537,10 +517,6 @@ class TestModels(TestCase, MoloTestCaseMixin):
             'recommended_articles-MAX_NUM_FORMS': 1000,
             'recommended_articles-MIN_NUM_FORMS': 0,
             'recommended_articles-TOTAL_FORMS': 0,
-            'reaction_questions-INITIAL_FORMS': 0,
-            'reaction_questions-MAX_NUM_FORMS': 1000,
-            'reaciction_questions-MIN_NUM_FORMS': 0,
-            'reaction_questions-TOTAL_FORMS': 0,
             'related_sections-INITIAL_FORMS': 0,
             'related_sections-MAX_NUM_FORMS': 1000,
             'related_sections-MIN_NUM_FORMS': 0,
@@ -701,10 +677,6 @@ class TestModels(TestCase, MoloTestCaseMixin):
             'recommended_articles-MAX_NUM_FORMS': 1000,
             'recommended_articles-MIN_NUM_FORMS': 0,
             'recommended_articles-TOTAL_FORMS': 0,
-            'reaction_questions-INITIAL_FORMS': 0,
-            'reaction_questions-MAX_NUM_FORMS': 1000,
-            'reaciction_questions-MIN_NUM_FORMS': 0,
-            'reaction_questions-TOTAL_FORMS': 0,
             'nav_tags-INITIAL_FORMS': 0,
             'nav_tags-MAX_NUM_FORMS': 1000,
             'nav_tags-MIN_NUM_FORMS': 0,
