@@ -11,10 +11,8 @@ from django.core.exceptions import PermissionDenied
 from django.core.paginator import Paginator, PageNotAnInteger, EmptyPage
 from django.urls import reverse
 from django.http import (
-    JsonResponse,
-    HttpResponse,
-    HttpResponseNotAllowed,
-    Http404,
+    JsonResponse, HttpResponse,
+    HttpResponseNotAllowed, Http404,
 )
 from django.shortcuts import redirect, get_object_or_404, render
 from django.utils.http import is_safe_url
@@ -23,8 +21,6 @@ from django.utils.translation import (
     get_language_from_request
 )
 from django.views.generic import ListView
-from django.views.generic.edit import FormView
-from django.views.generic.base import TemplateView
 from django.utils.translation import ugettext as _
 from django.contrib.sitemaps import views as sitemap_views
 
@@ -36,13 +32,12 @@ from wagtail.contrib.sitemaps.sitemap_generator import Sitemap
 from molo.core.utils import generate_slug, get_locale_code, update_media_file
 from molo.core.models import (
     ArticlePage, Languages, SiteSettings, Tag,
-    ArticlePageTags, SectionPage, ReactionQuestionChoice,
-    ReactionQuestionResponse, ReactionQuestion,
+    ArticlePageTags, SectionPage,
     TranslatablePageMixinNotRoutable)
 
 from molo.core.templatetags.core_tags import get_pages
 from molo.core.known_plugins import known_plugins
-from molo.core.forms import MediaForm, ReactionQuestionChoiceForm
+from molo.core.forms import MediaForm
 from molo.core.tasks import copy_to_all_task
 
 from el_pagination.decorators import page_template
@@ -198,101 +193,6 @@ def get_pypi_version(plugin_name):
         return 'request failed'
 
 
-class ReactionQuestionChoiceFeedbackView(TemplateView):
-    template_name = 'patterns/basics/articles/reaction_question_feedback.html'
-
-    def get_context_data(self, **kwargs):
-        context = super(ReactionQuestionChoiceFeedbackView,
-                        self).get_context_data(**kwargs)
-        locale = self.request.LANGUAGE_CODE
-        choice_slug = self.kwargs.get('choice_slug')
-        context['request'] = self.request
-        main_lang_choice = ReactionQuestionChoice.objects.descendant_of(
-            self.request.site.root_page).filter(
-            slug=choice_slug)
-        choice = get_pages(context, main_lang_choice, locale)
-        if choice:
-            choice = choice[0]
-        else:
-            choice = main_lang_choice
-        context.update({'choice': choice})
-        article_slug = self.kwargs.get('article_slug')
-        article = ArticlePage.objects.descendant_of(
-            self.request.site.root_page).filter(slug=article_slug).first()
-        context.update({'article': article})
-        return context
-
-
-class ReactionQuestionChoiceView(FormView):
-    form_class = ReactionQuestionChoiceForm
-    template_name = 'patterns/basics/articles/reaction_question.html'
-    success_url = '/'
-
-    def get_success_url(self, *args, **kwargs):
-        article_slug = self.kwargs.get('article_slug')
-        article = ArticlePage.objects.descendant_of(
-            self.request.site.root_page).filter(slug=article_slug).first()
-        if not article:
-            raise Http404
-        choice_id = self.get_context_data()['form'].data.get('choice')
-        choice = get_object_or_404(ReactionQuestionChoice, pk=choice_id)
-        question_id = self.kwargs.get('question_id')
-        return reverse('reaction-feedback', kwargs={
-            'question_id': question_id, 'article_slug': article.slug,
-            'choice_slug': choice.slug})
-
-    def get_context_data(self, *args, **kwargs):
-        context = super(
-            ReactionQuestionChoiceView, self).get_context_data(*args, **kwargs)
-        question_id = self.kwargs.get('question_id')
-        question = get_object_or_404(ReactionQuestion, pk=question_id)
-        context.update({'question': question})
-        return context
-
-    def form_valid(self, form, *args, **kwargs):
-        question_id = self.kwargs.get('question_id')
-        question = get_object_or_404(ReactionQuestion, pk=question_id)
-        question = question.get_main_language_page().specific
-        choice_pk = form.cleaned_data['choice']
-        choice = get_object_or_404(ReactionQuestionChoice, pk=choice_pk)
-        article_slug = self.kwargs.get('article_slug')
-        # get main language article and store the vote there
-        article = ArticlePage.objects.descendant_of(
-            self.request.site.root_page).filter(slug=article_slug).first()
-        if hasattr(article, 'get_main_language_page'):
-            article = article.get_main_language_page()
-        if not article:
-            raise Http404
-        if not question.has_user_submitted_reaction_response(
-                self.request, question_id, article.pk):
-            created = ReactionQuestionResponse.objects.create(
-                question=question,
-                article=article)
-            if created:
-                created.choice = choice
-                created.save()
-                created.set_response_as_submitted_for_session(
-                    self.request, article)
-            if self.request.user.is_authenticated:
-                created.user = self.request.user
-                created.save()
-
-        else:
-            if 'ajax' in self.request.POST and \
-                    self.request.POST['ajax'] == 'True':
-                response = ReactionQuestionResponse.objects.filter(
-                    article=article.pk, question=question_id,
-                    user=self.request.user).last()
-                response.choice = choice
-                response.save()
-            else:
-                messages.error(
-                    self.request,
-                    "You have already given feedback on this article.")
-        return super(ReactionQuestionChoiceView, self).form_valid(
-            form, *args, **kwargs)
-
-
 class TagsListView(ListView):
     template_name = "core/article_tags.html"
 
